@@ -106,11 +106,12 @@ class ApacheConfigBuilder(object):
         admin_paths = ''
         admin_paths += '^%s$' % self.url_scheme.url_for('home')
         extra_paths = [
-                self.url_scheme.url_for('person'),
-                self.url_scheme.url_for('project'),
-                self.url_scheme.url_for('admin'),
+                self.url_scheme.url_for('access_denied'),
                 self.url_scheme.url_for('login'),
                 self.url_scheme.url_for('logout'),
+                self.url_scheme.url_for('admin'),
+                self.url_scheme.url_for('person'),
+                self.url_scheme.url_for('project'),
                 ]
         for path in extra_paths:
             admin_paths += '|^%s($|/.*)' % path
@@ -129,7 +130,6 @@ class ApacheConfigBuilder(object):
         <LocationMatch "%s" >
             %s
             SetHandler python-program
-            PythonInterpreter kforge_interpreter
             PythonPath "'%s'.split(':') + sys.path"
             PythonHandler django.core.handlers.modpython
             PythonDebug %s
@@ -237,12 +237,12 @@ class ApacheConfigBuilder(object):
             PythonAccessHandler kforge.handlers.projecthost::accesshandler
             PythonAuthenHandler kforge.handlers.projecthost::authenhandler
             AuthType basic
-            AuthUserFile /dev/null
             AuthName "%s Restricted Area"
             Require valid-user
             # Only available in mod_auth_basic available in apache >= 2.1
             <IfModule mod_auth_basic.c>
                 AuthBasicAuthoritative Off
+                AuthUserFile /dev/null
             </IfModule>
             """ % (
                 self.systemConfigEnvVarName,
