@@ -10,7 +10,6 @@ from kforge.testunit import TestCase
 def suite():
     suites = [
         unittest.makeSuite(ApacheConfigBuilderTest),
-#        unittest.makeSuite(VirtualHostBuilderTest),
     ]
     return unittest.TestSuite(suites)
 
@@ -52,17 +51,23 @@ class ApacheConfigBuilderTest(TestCase):
         out = self.configBuilder.getDjangoHandledPaths()
         exp = '^/$|'
         self.failUnlessFragInFrag(exp, out)
-        exp = '|^/person($|/.*)'
-        self.failUnlessFragInFrag(exp, out)
+        exps = [ '|^/person($|/.*)',
+                '|^/admin($|/.*)',
+                '|^/project($|/.*)',
+                '|^/login($|/.*)',
+                '|^/logout($|/.*)',
+                '|^/accessDenied($|/.*)',
+                ]
+        for exp in exps:
+            self.failUnlessFragInFrag(exp, out)
 
 
 class ApachectlConfigtestTest(ApacheConfigBuilderTest):
+    '''KForge generated config file must be being loaded by Apache
+       as o/w test does nothing.
+    '''
 
     def testAllConfig(self):
-        # todo: Rewrite comment in English. Identify what 'this' is 
-        # todo: and how it might be 'linked'.
-        ## assumes you have linked this in so that Apache picks up the config
-        ## file
         self.configBuilder.buildConfig()
         # todo: Move 'apachectl' assumption to system dictionary.
         # todo: Make apachectl script path configurable.
