@@ -9,7 +9,12 @@ class ModelBuilder(dm.dom.builder.ModelBuilder):
         self.loadService()
         self.loadMember()
 
-    def loadPerson(self):  # override core model's Person
+    def loadPlugin(self):  # Replace dm.dom.plugin.Plugin.
+        from kforge.dom.plugin import Plugin
+        self.registry.registerDomainClass(Plugin)
+        self.registry.plugins = Plugin.createRegister()
+
+    def loadPerson(self):  # Replace dm.dom.person.Person.
         from kforge.dom.person import Person
         self.registry.registerDomainClass(Person)
         self.registry.persons = Person.createRegister()
@@ -37,3 +42,6 @@ class ModelBuilder(dm.dom.builder.ModelBuilder):
         self.registry.registerDomainClass(Member)
         self.registry.members = Member.createRegister()
 
+    def loadImage(self): # Replace dm.dom stuff -- kforge does not need Image
+        pass
+
