@@ -18,3 +18,6 @@ class Person(dm.dom.person.Person):
             member.purge()
         super(Person, self).purge()
 
+    def getLabelValue(self):
+        return self.fullname or self.name
+
