@@ -1,6 +1,30 @@
 """
 KForge Trac plugin.
 
+Installing this plugin allows users to create trac services to provide trac
+installations associated with their project.
+
+## Installation ##
+
+1. To create services using this plugin you must have installed the following
+   external applications:
+
+   * trac
+   * mod-python (this should already be installed for KForge itself to run)
+
+2. KForge config file. Add the following to your KForge configuration file
+   setting the variables as needed for your system:
+
+[trac]
+# path to trac templates
+templates_path = /usr/share/trac/templates
+# path to htdocs files
+htdocs_path = /usr/share/trac/htdocs
+# trac admin script
+admin_script = trac-admin
+
+3. Install and enable this plugin in the usual way (see the KForge
+   Documentation for details)
 """
 import kforge.plugin.base
 from kforge.plugin.trac.command import TracProjectEnvironmentCreate
